[llvm] a0d496d - [NewPassManager] Rename AM to OuterAM in the OuterAnalysisManagerProxy [NFCI].

Alina Sbirlea via llvm-commits llvm-commits at lists.llvm.org
Thu Jan 2 09:43:37 PST 2020


Author: Alina Sbirlea
Date: 2020-01-02T09:42:53-08:00
New Revision: a0d496d5b06b002161a2ad012738857a0a9660bb

URL: https://github.com/llvm/llvm-project/commit/a0d496d5b06b002161a2ad012738857a0a9660bb
DIFF: https://github.com/llvm/llvm-project/commit/a0d496d5b06b002161a2ad012738857a0a9660bb.diff

LOG: [NewPassManager] Rename AM to OuterAM in the OuterAnalysisManagerProxy [NFCI].

Provides clarity and consistency with the InnerAnalysisManagerProxy.

Added: 
    

Modified: 
    llvm/include/llvm/IR/PassManager.h

Removed: 
    


################################################################################
diff  --git a/llvm/include/llvm/IR/PassManager.h b/llvm/include/llvm/IR/PassManager.h
index 1e1f4a92f844..58591ab380cc 100644
--- a/llvm/include/llvm/IR/PassManager.h
+++ b/llvm/include/llvm/IR/PassManager.h
@@ -1165,9 +1165,9 @@ class OuterAnalysisManagerProxy
   /// Result proxy object for \c OuterAnalysisManagerProxy.
   class Result {
   public:
-    explicit Result(const AnalysisManagerT &AM) : AM(&AM) {}
+    explicit Result(const AnalysisManagerT &OuterAM) : OuterAM(&OuterAM) {}
 
-    const AnalysisManagerT &getManager() const { return *AM; }
+    const AnalysisManagerT &getManager() const { return *OuterAM; }
 
     /// When invalidation occurs, remove any registered invalidation events.
     bool invalidate(
@@ -1219,7 +1219,7 @@ class OuterAnalysisManagerProxy
     }
 
   private:
-    const AnalysisManagerT *AM;
+    const AnalysisManagerT *OuterAM;
 
     /// A map from an outer analysis ID to the set of this IR-unit's analyses
     /// which need to be invalidated.
@@ -1227,14 +1227,15 @@ class OuterAnalysisManagerProxy
         OuterAnalysisInvalidationMap;
   };
 
-  OuterAnalysisManagerProxy(const AnalysisManagerT &AM) : AM(&AM) {}
+  OuterAnalysisManagerProxy(const AnalysisManagerT &OuterAM)
+      : OuterAM(&OuterAM) {}
 
   /// Run the analysis pass and create our proxy result object.
   /// Nothing to see here, it just forwards the \c AM reference into the
   /// result.
   Result run(IRUnitT &, AnalysisManager<IRUnitT, ExtraArgTs...> &,
              ExtraArgTs...) {
-    return Result(*AM);
+    return Result(*OuterAM);
   }
 
 private:
@@ -1243,7 +1244,7 @@ class OuterAnalysisManagerProxy
 
   static AnalysisKey Key;
 
-  const AnalysisManagerT *AM;
+  const AnalysisManagerT *OuterAM;
 };
 
 template <typename AnalysisManagerT, typename IRUnitT, typename... ExtraArgTs>
@@ -1227,14 +1227,15 @@ class OuterAnalysisManagerProxy
 
   /// Run the analysis pass and create our proxy result object.
-  /// Nothing to see here, it just forwards the \c AM reference into the
+  /// Nothing to see here, it just forwards the \c OuterAM reference into the
   /// result.
   Result run(IRUnitT &, AnalysisManager<IRUnitT, ExtraArgTs...> &,


        


More information about the llvm-commits mailing list